@@ -1,5 +1,3 @@
-from pandagg.tree.aggs.aggs import Aggs
-
 from pandagg.node.aggs.bucket import (
     Terms,
     Filters,
@@ -11,8 +9,11 @@ from pandagg.node.aggs.bucket import (
     ReverseNested,
     Range,
     Missing,
+    MatchAll,
 )
 
+from pandagg.node.aggs.composite import Composite
+
 from pandagg.node.aggs.metric import (
     Avg,
     Max,
@@ -46,6 +47,8 @@ from pandagg.node.aggs.pipeline import (
     SerialDiff,
 )
 
+from pandagg.tree.aggs import Aggs
+
 __all__ = [
     "Aggs",
     "Terms",
@@ -85,4 +88,6 @@ __all__ = [
     "BucketSelector",
     "BucketSort",
     "SerialDiff",
+    "MatchAll",
+    "Composite",
 ]
