@@ -1,3 +1,3 @@
-from .aggs import *
-from .mapping import *
 from .query import *
+from .aggs import *
+from .mappings import *
