@@ -1,10 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
-
-from future.utils import iteritems
-
 from lighttree import Node as OriginalNode
 
 from pandagg.utils import DSLMixin
@@ -20,7 +16,7 @@ class Node(DSLMixin, OriginalNode):
     @staticmethod
     def expand__to_dot(params):
         nparams = {}
-        for pname, pvalue in iteritems(params):
+        for pname, pvalue in params.items():
             if "__" in pname:
                 pname = pname.replace("__", ".")
             nparams[pname] = pvalue
