@@ -1,16 +1,59 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
-from builtins import str as text
-
 import json
 
 from pandagg.node._node import Node
 
 
-class AggNode(Node):
-    """Wrapper around elasticsearch aggregation concept.
+def A(name, type_or_agg=None, **body):
+    """
+    Accept multiple syntaxes, return a AggNode instance.
+
+    :param type_or_agg:
+    :param body:
+    :return: AggNode
+    """
+    if isinstance(type_or_agg, str):
+        # _translate_agg("per_user", "terms", field="user")
+        return AggClause._get_dsl_class(type_or_agg)(**body)
+    if isinstance(type_or_agg, AggClause):
+        # _translate_agg("per_user", Terms(field='user'))
+        if body:
+            raise ValueError(
+                'Body cannot be added using "AggNode" declaration, got %s.' % body
+            )
+        return type_or_agg
+    if isinstance(type_or_agg, dict):
+        # _translate_agg("per_user", {"terms": {"field": "user"}})
+        if body:
+            raise ValueError(
+                'Body cannot be added using "dict" agg declaration, got %s.' % body
+            )
+        type_or_agg = type_or_agg.copy()
+        children_aggs = (
+            type_or_agg.pop("aggs", None) or type_or_agg.pop("aggregations", None) or {}
+        )
+        if len(type_or_agg) != 1:
+            raise ValueError(
+                "Invalid aggregation declaration (two many keys): got <%s>"
+                % type_or_agg
+            )
+        type_, body_ = type_or_agg.popitem()
+        body_ = body_.copy()
+        if children_aggs:
+            body_["aggs"] = children_aggs
+        return AggClause._get_dsl_class(type_)(**body_)
+    if type_or_agg is None:
+        # if type_or_agg is not provided, by default execute a terms aggregation
+        # _translate_agg("per_user")
+        return AggClause._get_dsl_class("terms")(field=name, **body)
+    raise ValueError('"type_or_agg" must be among "dict", "AggNode", "str"')
+
+
+class AggClause(Node):
+    """
+    Wrapper around elasticsearch aggregation concept.
     https://www.elastic.co/guide/en/elasticsearch/reference/2.3/search-aggregations.html
 
     Each aggregation can be seen both a Node that can be encapsulated in a parent agg.
@@ -29,13 +72,13 @@ class AggNode(Node):
         self.body = body
         self.meta = meta
         self._children = {}
-        super(AggNode, self).__init__(identifier=identifier)
+        super(AggClause, self).__init__(identifier=identifier)
 
     def line_repr(self, depth, **kwargs):
         # root node
         if self.KEY is None:
             return "_", ""
-        repr_args = [text(self.KEY)]
+        repr_args = [str(self.KEY)]
         if self.body:
             repr_args.append(self._params_repr(self.body))
         unnamed = "<%s>" % ", ".join(repr_args)
@@ -45,7 +88,7 @@ class AggNode(Node):
     def _params_repr(params):
         params = params or {}
         return ", ".join(
-            "%s=%s" % (text(k), text(json.dumps(params[k], sort_keys=True)))
+            "%s=%s" % (str(k), str(json.dumps(params[k], sort_keys=True)))
             for k in sorted(params.keys())
         )
 
@@ -55,10 +98,13 @@ class AggNode(Node):
             return field_type in cls.WHITELISTED_MAPPING_TYPES
         if cls.BLACKLISTED_MAPPING_TYPES is not None:
             return field_type not in cls.BLACKLISTED_MAPPING_TYPES
-        return False
+        # by default laxist
+        # TODO - constraint to only allowed types
+        return True
 
     def to_dict(self):
-        """ElasticSearch aggregation queries follow this formatting::
+        """
+        ElasticSearch aggregation queries follow this formatting::
 
             {
                 "<aggregation_name>" : {
@@ -84,7 +130,9 @@ class AggNode(Node):
         return aggs
 
     def get_filter(self, key):
-        """Return filter query to list documents having this aggregation key.
+        """
+        Return filter query to list documents having this aggregation key.
+
         :param key: string
         :return: elasticsearch filter query
         """
@@ -102,20 +150,22 @@ class AggNode(Node):
 
     def __str__(self):
         return "<{class_}, type={type}, body={body}>".format(
-            class_=text(self.__class__.__name__),
-            type=text(self.KEY),
+            class_=str(self.__class__.__name__),
+            type=str(self.KEY),
             body=json.dumps(self.body),
         )
 
     def __eq__(self, other):
-        if isinstance(other, AggNode):
+        if isinstance(other, AggClause):
             return other.to_dict() == self.to_dict()
         # make sure we still equal to a dict with the same data
         return other == self.to_dict()
 
 
-class Root(AggNode):
-    """Not a real aggregation. Just the initial empty dict."""
+class Root(AggClause):
+    """
+    Not a real aggregation. Just the initial empty dict (used as lighttree.Tree root).
+    """
 
     KEY = "_root"
 
@@ -130,8 +180,10 @@ class Root(AggNode):
         return None
 
 
-class MetricAgg(AggNode):
-    """Metric aggregation are aggregations providing a single bucket, with value attributes to be extracted."""
+class MetricAgg(AggClause):
+    """
+    Metric aggregation are aggregations providing a single bucket, with value attributes to be extracted.
+    """
 
     VALUE_ATTRS = None
 
@@ -142,8 +194,9 @@ class MetricAgg(AggNode):
         return None
 
 
-class BucketAggNode(AggNode):
-    """Bucket aggregation have special abilities: they can encapsulate other aggregations as children.
+class BucketAggClause(AggClause):
+    """
+    Bucket aggregation have special abilities: they can encapsulate other aggregations as children.
     Each time, the extracted value is a 'doc_count'.
 
     Provide methods:
@@ -168,7 +221,7 @@ class BucketAggNode(AggNode):
         self.body = body
         self.meta = meta
         self._children = body.pop("aggs", None) or body.pop("aggregations", None) or {}
-        super(AggNode, self).__init__(identifier=identifier)
+        super(AggClause, self).__init__(identifier=identifier)
 
     def extract_buckets(self, response_value):
         raise NotImplementedError()
@@ -178,7 +231,7 @@ class BucketAggNode(AggNode):
         raise NotImplementedError()
 
 
-class UniqueBucketAgg(BucketAggNode):
+class UniqueBucketAgg(BucketAggClause):
     """Aggregations providing a single bucket."""
 
     VALUE_ATTRS = None
@@ -190,13 +243,14 @@ class UniqueBucketAgg(BucketAggNode):
         raise NotImplementedError()
 
 
-class MultipleBucketAgg(BucketAggNode):
+class MultipleBucketAgg(BucketAggClause):
 
     VALUE_ATTRS = None
     IMPLICIT_KEYED = False
 
     def __init__(self, keyed=None, key_path="key", meta=None, **body):
-        """Aggregation that return either a list or a map of buckets.
+        """
+        Aggregation that return either a list or a map of buckets.
 
         If keyed, ES buckets are expected as dict, else as list (in this case key_path is used to extract key from each
         list item).
@@ -229,13 +283,19 @@ class MultipleBucketAgg(BucketAggNode):
 
 
 class FieldOrScriptMetricAgg(MetricAgg):
-    """Metric aggregation based on single field."""
+    """
+    Metric aggregation based on single field.
+    """
 
     VALUE_ATTRS = None
 
-    def __init__(self, meta=None, **body):
-        self.field = body.get("field")
-        self.script = body.get("script")
+    def __init__(self, field=None, script=None, meta=None, **body):
+        self.field = field
+        self.script = script
+        if field is not None:
+            body["field"] = field
+        if script is not None:
+            body["script"] = script
         super(FieldOrScriptMetricAgg, self).__init__(meta=meta, **body)
 
 
