@@ -1,17 +1,13 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-from __future__ import unicode_literals
-
 import copy
 
-from builtins import str as text
-
 from future.utils import iterkeys, iteritems
 
 from pandagg.interactive.response import IResponse
 from pandagg.node.aggs.abstract import UniqueBucketAgg, MetricAgg, Root
-from pandagg.node.aggs.bucket import Nested
+from pandagg.node.aggs.bucket import Nested, ReverseNested
 from pandagg.tree.response import AggsResponseTree
 
 
@@ -102,9 +98,9 @@ class Hits:
 
     def __repr__(self):
         if not isinstance(self.total, dict):
-            total_repr = text(self.total)
+            total_repr = str(self.total)
         elif self.total.get("relation") == "eq":
-            total_repr = text(self.total["value"])
+            total_repr = str(self.total["value"])
         elif self.total.get("relation") == "gte":
             total_repr = ">%d" % self.total["value"]
         else:
@@ -162,52 +158,56 @@ class Aggregations:
         row_as_tuple=False,
         with_single_bucket_groups=False,
     ):
-        """Recursive parsing of succession of grouping aggregation clauses.
+        """
+        Recursive parsing of succession of grouping aggregation clauses.
 
         Yields each row for which last bucket aggregation generated buckets.
         """
-        # initialization: find ancestors once for faster computation
+        # initialization: cache ancestors once for faster computation, that will be passed as arguments to downside
+        # recursive calls
         if ancestors is None:
             until_id = self._aggs.id_from_key(until)
             ancestors = self._aggs.ancestors(until_id, include_current=True)
-            # remove eventual fake root
-            ancestors = [(k, n) for k, n in ancestors if k is not None]
+            # remove root (not an aggregation clause)
+            ancestors = [(k, n) for k, n in ancestors[:-1]]
             agg_name, agg_node = ancestors[-1]
+
+        if agg_name not in response:
+            return
+
         if not row:
             row = [] if row_as_tuple else {}
-        if agg_name in response:
-            agg_node = [n for k, n in ancestors if k == agg_name][0]
-            for key, raw_bucket in agg_node.extract_buckets(response[agg_name]):
-                sub_row = copy.copy(row)
-                if (
-                    not isinstance(agg_node, UniqueBucketAgg)
-                    or with_single_bucket_groups
-                ):
-                    if row_as_tuple:
-                        sub_row.append(key)
-                    else:
-                        sub_row[agg_name] = key
-                if agg_name == until:
-                    # end real yield
-                    if row_as_tuple:
-                        yield tuple(sub_row), raw_bucket
-                    else:
-                        yield sub_row, raw_bucket
-                elif agg_name in {k for k, _ in ancestors}:
-                    # yield children
-                    for child_key, _ in self._aggs.children(agg_node.identifier):
-                        for nrow, nraw_bucket in self._parse_group_by(
-                            row=sub_row,
-                            response=raw_bucket,
-                            agg_name=child_key,
-                            until=until,
-                            row_as_tuple=row_as_tuple,
-                            ancestors=ancestors,
-                        ):
-                            yield nrow, nraw_bucket
+
+        agg_node = [n for k, n in ancestors if k == agg_name][0]
+        for key, raw_bucket in agg_node.extract_buckets(response[agg_name]):
+            sub_row = copy.copy(row)
+            if not isinstance(agg_node, UniqueBucketAgg) or with_single_bucket_groups:
+                if row_as_tuple:
+                    sub_row.append(key)
+                else:
+                    sub_row[agg_name] = key
+            if agg_name == until:
+                # end real yield
+                if row_as_tuple:
+                    yield tuple(sub_row), raw_bucket
+                else:
+                    yield sub_row, raw_bucket
+            elif agg_name in {k for k, _ in ancestors}:
+                # yield children
+                for child_key, _ in self._aggs.children(agg_node.identifier):
+                    for nrow, nraw_bucket in self._parse_group_by(
+                        row=sub_row,
+                        response=raw_bucket,
+                        agg_name=child_key,
+                        until=until,
+                        row_as_tuple=row_as_tuple,
+                        ancestors=ancestors,
+                    ):
+                        yield nrow, nraw_bucket
 
     def _normalize_buckets(self, agg_response, agg_name=None):
-        """Recursive function to parse aggregation response as a normalized entities.
+        """
+        Recursive function to parse aggregation response as a normalized entities.
         Each response bucket is represented as a dict with keys (key, level, value, children)::
 
             {
@@ -240,31 +240,29 @@ class Aggregations:
             yield result
 
     def _grouping_agg(self, name=None):
-        """Return aggregation node that used as grouping node.
+        """
+        Return aggregation node that used as grouping node.
         Note: in case there is only a nested aggregation below that node, group-by nested clause.
         """
-        # if provided
         if name is not None:
+            # override existing groupby_ptr
             id_ = self._aggs.id_from_key(name)
             if not self._aggs._is_eligible_grouping_node(id_):
                 raise ValueError(
                     "Cannot group by <%s>, not a valid grouping aggregation" % name
                 )
             key, node = self._aggs.get(id_)
-            # if parent of single nested clause and nested_autocorrect
-            if self._aggs.nested_autocorrect:
-                children = self._aggs.children(node.identifier)
-                if len(children) == 1:
-                    child_key, child_node = children[0]
-                    if isinstance(child_node, Nested):
-                        return child_key, child_node
-            return key, node
-        # if use of groupby method in Aggs class, use groupby pointer
-        if self._aggs._groupby_ptr is not None:
-            return self._aggs.get(self._aggs._groupby_ptr)
+        else:
+            key, node = self._aggs.get(self._aggs._groupby_ptr)
 
-        id_ = self._aggs.deepest_linear_bucket_agg
-        return self._aggs.get(id_)
+        # if parent of single nested clause and nested_autocorrect
+        if self._aggs.nested_autocorrect:
+            children = self._aggs.children(node.identifier)
+            if len(children) == 1:
+                child_key, child_node = children[0]
+                if isinstance(child_node, (Nested, ReverseNested)):
+                    return child_key, child_node
+        return key, node
 
     def to_tabular(
         self,
@@ -275,7 +273,8 @@ class Aggregations:
         normalize=True,
         with_single_bucket_groups=False,
     ):
-        """Build tabular view of ES response grouping levels (rows) until 'grouped_by' aggregation node included is
+        """
+        Build tabular view of ES response grouping levels (rows) until 'grouped_by' aggregation node included is
         reached, and using children aggregations of grouping level as values for each of generated groups (columns).
 
         Suppose an aggregation of this shape (A & B bucket aggregations)::
@@ -296,7 +295,7 @@ class Aggregations:
         :param index_orient: if True, level-key samples are returned as tuples, else in a dictionnary
         :param grouped_by: name of the aggregation node used as last grouping level
         :param normalize: if True, normalize columns buckets
-        :return: index, index_names, values
+        :return: index_names, values
         """
         grouping_key, grouping_agg = self._grouping_agg(grouped_by)
         if grouping_key is None:
@@ -434,9 +433,9 @@ class Aggregations:
         elif output == "dataframe":
             return self.to_dataframe(**kwargs)
         else:
-            raise NotImplementedError("Unkown %s output format." % output)
+            raise NotImplementedError("Unknown %s output format." % output)
 
     def __repr__(self):
         if not self.keys():
             return "<Aggregations> empty"
-        return "<Aggregations> %s" % list(map(text, self.keys()))
+        return "<Aggregations> %s" % list(map(str, self.keys()))
