@@ -3,15 +3,13 @@ import copy
 import json
 
 from elasticsearch.helpers import scan
-from future.utils import string_types
-from lighttree.exceptions import NotFoundNodeError
 
 from pandagg.connections import get_connection
 from pandagg.query import Bool
 from pandagg.response import Response
-from pandagg.tree.mapping import _mapping
-from pandagg.tree.query.abstract import Query, ADD
-from pandagg.tree.aggs.aggs import Aggs
+from pandagg.tree.mappings import _mappings
+from pandagg.tree.query import Query, ADD
+from pandagg.tree.aggs import Aggs
 from pandagg.utils import DSLMixin
 
 
@@ -63,7 +61,7 @@ class Request(object):
         else:
             indexes = []
             for i in index:
-                if isinstance(i, string_types):
+                if isinstance(i, str):
                     indexes.append(i)
                 elif isinstance(i, list):
                     indexes += i
@@ -104,7 +102,7 @@ class Search(DSLMixin, Request):
         self,
         using=None,
         index=None,
-        mapping=None,
+        mappings=None,
         nested_autocorrect=False,
         repr_auto_execute=False,
     ):
@@ -113,12 +111,12 @@ class Search(DSLMixin, Request):
 
         :arg using: `Elasticsearch` instance to use
         :arg index: limit the search to index
-        :arg mapping: mapping used for query validation
+        :arg mappings: mappings used for query validation
         :arg nested_autocorrect: in case of missing nested clause, will insert it automatically
         :arg repr_auto_execute: execute query and display results as dataframe, requires client to be provided
 
         All the parameters supplied (or omitted) at creation type can be later
-        overridden by methods (`using`, `index` and `mapping` respectively).
+        overridden by methods (`using`, `index` and `mappings` respectively).
         """
 
         self._sort = []
@@ -127,12 +125,12 @@ class Search(DSLMixin, Request):
         self._highlight_opts = {}
         self._suggest = {}
         self._script_fields = {}
-        mapping = _mapping(mapping)
-        self._mapping = mapping
-        self._aggs = Aggs(mapping=mapping, nested_autocorrect=nested_autocorrect)
-        self._query = Query(mapping=mapping, nested_autocorrect=nested_autocorrect)
+        mappings = _mappings(mappings)
+        self._mappings = mappings
+        self._aggs = Aggs(mappings=mappings, nested_autocorrect=nested_autocorrect)
+        self._query = Query(mappings=mappings, nested_autocorrect=nested_autocorrect)
         self._post_filter = Query(
-            mapping=mapping, nested_autocorrect=nested_autocorrect
+            mappings=mappings, nested_autocorrect=nested_autocorrect
         )
         self._repr_auto_execute = repr_auto_execute
         super(Search, self).__init__(using=using, index=index)
@@ -264,7 +262,7 @@ class Search(DSLMixin, Request):
         """Must not wrapped in filter context."""
         s = self._clone()
         s._query = s._query.filter(
-            Bool(must_not=Query._translate_query(type_or_query=type_or_query, **body)),
+            Bool(must_not=Query._q(type_or_query=type_or_query, **body)),
             insert_below=insert_below,
             on=on,
             mode=mode,
@@ -339,22 +337,15 @@ class Search(DSLMixin, Request):
             s._params["from"] = n.start or 0
             s._params["size"] = n.stop - (n.start or 0) if n.stop is not None else 10
             return s
-        elif isinstance(n, list):
-            # Columns selection
-            if self._mapping:
-                for key in n:
-                    try:
-                        self._mapping.id_from_key(key)
-                    except NotFoundNodeError:
-                        raise KeyError("%s not in index" % key)
-            return self.source(includes=n)
-        else:  # This is an index lookup, equivalent to slicing by [n:n+1].
-            # If negative index, abort.
-            if n < 0:
-                raise ValueError("Search does not support negative indexing.")
-            s._params["from"] = n
-            s._params["size"] = 1
-            return s
+        if isinstance(n, list):
+            return s.source(includes=n)
+        # This is an index lookup, equivalent to slicing by [n:n+1].
+        # If negative index, abort.
+        if n < 0:
+            raise ValueError("Search does not support negative indexing.")
+        s._params["from"] = n
+        s._params["size"] = 1
+        return s
 
     def size(self, size):
         """
@@ -395,7 +386,9 @@ class Search(DSLMixin, Request):
         of all the underlying objects. Used internally by most state modifying
         APIs.
         """
-        s = self.__class__(using=self._using, index=self._index, mapping=self._mapping)
+        s = self.__class__(
+            using=self._using, index=self._index, mappings=self._mappings
+        )
         s._params = self._params.copy()
         s._sort = self._sort[:]
         s._source = copy.copy(self._source) if self._source is not None else None
@@ -406,7 +399,7 @@ class Search(DSLMixin, Request):
         s._aggs = self._aggs.clone()
         s._query = self._query.clone()
         s._post_filter = self._post_filter.clone()
-        s._mapping = None if self._mapping is None else self._mapping.clone()
+        s._mappings = None if self._mappings is None else self._mappings.clone()
         s._repr_auto_execute = self._repr_auto_execute
         return s
 
@@ -465,7 +458,7 @@ class Search(DSLMixin, Request):
         """
         s = self._clone()
         for name in kwargs:
-            if isinstance(kwargs[name], string_types):
+            if isinstance(kwargs[name], str):
                 kwargs[name] = {"script": kwargs[name]}
         s._script_fields.update(kwargs)
         return s
@@ -541,7 +534,7 @@ class Search(DSLMixin, Request):
         s = self._clone()
         s._sort = []
         for k in keys:
-            if isinstance(k, string_types) and k.startswith("-"):
+            if isinstance(k, str) and k.startswith("-"):
                 if k[1:] == "_score":
                     raise ValueError("Sorting by `-_score` is not allowed.")
                 k = {k[1:]: {"order": "desc"}}
