@@ -1,3 +1,3 @@
 from .aggs import *
 from .query import *
-from .mapping import *
+from .mappings import *
