@@ -7,19 +7,15 @@
 
 from __future__ import unicode_literals
 from unittest import TestCase
-from lighttree.exceptions import NotFoundNodeError
 from mock import patch
 
-from pandagg.tree.aggs.aggs import Aggs
-from pandagg.exceptions import (
-    AbsentMappingFieldError,
-    InvalidOperationMappingFieldError,
-)
-from pandagg.aggs import DateHistogram, Terms, Filter, Avg, Min
+from pandagg.tree.aggs import Aggs
+from pandagg.exceptions import InvalidOperationMappingFieldError
+from pandagg.aggs import DateHistogram, Terms, Avg, Min, Filter
 
 import tests.testing_samples.data_sample as sample
 
-from tests.testing_samples.mapping_example import MAPPING
+from tests.testing_samples.mapping_example import MAPPINGS
 
 
 class AggTestCase(TestCase):
@@ -105,7 +101,7 @@ genres                                           <terms, field="genres", size=3>
             )
 
     def test_add_node_with_mapping(self):
-        with_mapping = Aggs(mapping=MAPPING, nested_autocorrect=True)
+        with_mapping = Aggs(mappings=MAPPINGS, nested_autocorrect=True)
 
         # add regular node
         with_mapping = with_mapping.agg("workflow", Terms(field="workflow"))
@@ -253,7 +249,7 @@ workflow                                               <terms, field="workflow">
                     }
                 }
             },
-            mapping=MAPPING,
+            mappings=MAPPINGS,
         )
         self.assertEqual({k for k, _ in initial_agg_1.list()}, {None, "week"})
         pasted_agg_1 = Aggs(
@@ -318,7 +314,7 @@ workflow                                               <terms, field="workflow">
                     }
                 }
             },
-            mapping=MAPPING,
+            mappings=MAPPINGS,
             nested_autocorrect=True,
         )
         self.assertEqual({k for k, _ in initial_agg_2.list()}, {None, "week"})
@@ -464,7 +460,7 @@ workflow                                               <terms, field="workflow">
         # with required nested
         some_agg = Aggs(
             {"term_workflow": {"terms": {"field": "workflow", "size": 5}}},
-            mapping=MAPPING,
+            mappings=MAPPINGS,
             nested_autocorrect=True,
         )
         some_agg = some_agg.agg(
@@ -499,7 +495,7 @@ workflow                                               <terms, field="workflow">
         # with parent with required nested
         some_agg = Aggs(
             {"term_workflow": {"terms": {"field": "workflow", "size": 5}}},
-            mapping=MAPPING,
+            mappings=MAPPINGS,
             nested_autocorrect=True,
         )
         node = Avg(field="local_metrics.performance.test.f1_score")
@@ -573,65 +569,10 @@ workflow                                               <terms, field="workflow">
             },
         )
 
-    # def test_validate_aggs_parent_id(self):
-    #     """
-    #     <Aggregation>
-    #     classification_type
-    #     └── global_metrics.field.name
-    #         ├── avg_f1_micro
-    #         └── avg_nb_classes
-    #     """
-    #     my_agg = Aggs(sample.EXPECTED_AGG_QUERY, mapping=MAPPING)
-    #
-    #     with self.assertRaises(ValueError) as e:
-    #         my_agg._validate_aggs_parent_id(pid=None)
-    #     self.assertEqual(
-    #         e.exception.args,
-    #         (
-    #             "Declaration is ambiguous, you must declare the node id under which these "
-    #             "aggregations should be placed.",
-    #         ),
-    #     )
-    #
-    #     with self.assertRaises(ValueError) as e:
-    #         my_agg._validate_aggs_parent_id("avg_f1_micro")
-    #     self.assertEqual(
-    #         e.exception.args, ("Node id <avg_f1_micro> is not a bucket aggregation.",)
-    #     )
-    #
-    #     self.assertEqual(
-    #         my_agg._validate_aggs_parent_id("global_metrics.field.name"),
-    #         "global_metrics.field.name",
-    #     )
-    #
-    #     with self.assertRaises(NotFoundNodeError) as e:
-    #         my_agg._validate_aggs_parent_id("non-existing-node")
-    #     self.assertEqual(
-    #         e.exception.args, ("Node id <non-existing-node> doesn't exist in tree",)
-    #     )
-    #
-    #     # linear agg
-    #     my_agg.drop_node("avg_f1_micro")
-    #     my_agg.drop_node("avg_nb_classes")
-    #     """
-    #     <Aggregation>
-    #     classification_type
-    #     └── global_metrics.field.name
-    #     """
-    #     self.assertEqual(
-    #         my_agg._validate_aggs_parent_id(None), "global_metrics.field.name"
-    #     )
-    #
-    #     # empty agg
-    #     agg = Aggs()
-    #     self.assertEqual(agg._validate_aggs_parent_id(None), None)
-    #
-    #     # TODO - pipeline aggregation under metric agg
-
     def test_init_from_node_hierarchy(self):
         node_hierarchy = sample.get_node_hierarchy()
 
-        agg = Aggs(node_hierarchy, mapping=MAPPING)
+        agg = Aggs(node_hierarchy, mappings=MAPPINGS)
         self.assertEqual(agg.to_dict(), sample.EXPECTED_AGG_QUERY)
 
         # with nested
@@ -652,7 +593,7 @@ workflow                                               <terms, field="workflow">
                 },
             )
         }
-        agg = Aggs(node_hierarchy, mapping=MAPPING, nested_autocorrect=True)
+        agg = Aggs(node_hierarchy, mappings=MAPPINGS, nested_autocorrect=True)
         self.assertEqual(
             agg.to_dict(),
             {
@@ -785,111 +726,6 @@ workflow                                               <terms, field="workflow">
             },
         )
 
-    # def test_groupby_insert_above(self):
-    #     a1 = Aggs({
-    #         "A": Terms(field="A", aggs={
-    #             "B": Terms(field="B"),
-    #             "C": Terms(field="C")
-    #         })
-    #     })
-    #     self.assertEqual(
-    #         a1.to_dict(),
-    #         {
-    #             "A": {
-    #                 "terms": {"field": "A"},
-    #                 "aggs": {
-    #                     "B": {"terms": {"field": "B"}},
-    #                     "C": {"terms": {"field": "C"}},
-    #                 },
-    #             }
-    #         },
-    #     )
-    #
-    #     self.assertEqual(
-    #         a1.groupby("D", Terms(field="D"), insert_above="B").to_dict(),
-    #         {
-    #             "A": {
-    #                 "terms": {"field": "A"},
-    #                 "aggs": {
-    #                     "C": {"terms": {"field": "C"}},
-    #                     "D": {
-    #                         "terms": {"field": "D"},
-    #                         "aggs": {"B": {"terms": {"field": "B"}}},
-    #                     },
-    #                 },
-    #             }
-    #         },
-    #     )
-    #     self.assertEqual(
-    #         a1.groupby(
-    #             [Terms("D", field="D"), Terms("E", field="E")], insert_above="B"
-    #         ).to_dict(),
-    #         {
-    #             "A": {
-    #                 "terms": {"field": "A"},
-    #                 "aggs": {
-    #                     "C": {"terms": {"field": "C"}},
-    #                     "D": {
-    #                         "terms": {"field": "D"},
-    #                         "aggs": {
-    #                             "E": {
-    #                                 "terms": {"field": "E"},
-    #                                 "aggs": {"B": {"terms": {"field": "B"}}},
-    #                             }
-    #                         },
-    #                     },
-    #                 },
-    #             }
-    #         },
-    #     )
-    #     self.assertEqual(
-    #         a1.groupby(
-    #             Terms("D", field="D", aggs=Terms("E", field="E")), insert_above="B"
-    #         ).to_dict(),
-    #         {
-    #             "A": {
-    #                 "aggs": {
-    #                     "C": {"terms": {"field": "C"}},
-    #                     "D": {
-    #                         "aggs": {
-    #                             "E": {
-    #                                 "aggs": {"B": {"terms": {"field": "B"}}},
-    #                                 "terms": {"field": "E"},
-    #                             }
-    #                         },
-    #                         "terms": {"field": "D"},
-    #                     },
-    #                 },
-    #                 "terms": {"field": "A"},
-    #             }
-    #         },
-    #     )
-    #     # above root
-    #     self.assertEqual(
-    #         a1.groupby(
-    #             Terms("D", field="D", aggs=Terms("E", field="E")), insert_above="A"
-    #         ).to_dict(),
-    #         {
-    #             "D": {
-    #                 "terms": {"field": "D"},
-    #                 "aggs": {
-    #                     "E": {
-    #                         "terms": {"field": "E"},
-    #                         "aggs": {
-    #                             "A": {
-    #                                 "terms": {"field": "A"},
-    #                                 "aggs": {
-    #                                     "B": {"terms": {"field": "B"}},
-    #                                     "C": {"terms": {"field": "C"}},
-    #                                 },
-    #                             }
-    #                         },
-    #                     }
-    #                 },
-    #             }
-    #         },
-    #     )
-
     def test_agg_insert_below(self):
         a1 = Aggs(
             {"A": Terms(field="A", aggs={"B": Terms(field="B"), "C": Terms(field="C")})}
@@ -960,7 +796,7 @@ workflow                                               <terms, field="workflow">
                 },
             )
         }
-        agg = Aggs(node_hierarchy, mapping=MAPPING, nested_autocorrect=True)
+        agg = Aggs(node_hierarchy, mappings=MAPPINGS, nested_autocorrect=True)
 
         self.assertEqual(agg.applied_nested_path_at_node(agg.id_from_key("week")), None)
         for node_key in (
@@ -973,58 +809,6 @@ workflow                                               <terms, field="workflow">
                 "local_metrics",
             )
 
-    def test_deepest_linear_agg(self):
-        # deepest_linear_bucket_agg
-        """
-        week
-        └── nested_below_week
-            └── local_metrics.field_class.name   <----- HERE because then metric aggregation
-                └── avg_f1_score
-        """
-        node_hierarchy = {
-            "week": DateHistogram(
-                field="date",
-                interval="1w",
-                aggs={
-                    "local_metrics.field_class.name": Terms(
-                        field="local_metrics.field_class.name",
-                        size=10,
-                        aggs={
-                            "min_f1_score": Min(
-                                field="local_metrics.performance.test.f1_score"
-                            )
-                        },
-                    )
-                },
-            )
-        }
-        agg = Aggs(node_hierarchy, mapping=MAPPING, nested_autocorrect=True)
-        self.assertEqual(
-            agg.get_key(agg.deepest_linear_bucket_agg), "local_metrics.field_class.name"
-        )
-
-        # week is last bucket linear bucket
-        node_hierarchy_2 = {
-            "week": DateHistogram(
-                field="date",
-                interval="1w",
-                aggs={
-                    "local_metrics.field_class.name": Terms(
-                        field="local_metrics.field_class.name", size=10
-                    ),
-                    "f1_score_above_threshold": Filter(
-                        filter={
-                            "range": {
-                                "local_metrics.performance.test.f1_score": {"gte": 0.5}
-                            }
-                        }
-                    ),
-                },
-            )
-        }
-        agg2 = Aggs(node_hierarchy_2, mapping=MAPPING, nested_autocorrect=True)
-        self.assertEqual(agg2.get_key(agg2.deepest_linear_bucket_agg), "week")
-
     def test_groupby_pointer(self):
         a = (
             Aggs()
@@ -1061,3 +845,111 @@ A                                                             <terms, field="a">
                 }
             },
         )
+
+    def test_deepest_linear_agg(self):
+        # deepest_linear_bucket_agg
+        """
+        week
+        └── nested_below_week
+            └── local_metrics.field_class.name   <----- HERE because then metric aggregation
+                └── avg_f1_score
+        """
+        node_hierarchy = {
+            "week": DateHistogram(
+                field="date",
+                interval="1w",
+                aggs={
+                    "local_metrics.field_class.name": Terms(
+                        field="local_metrics.field_class.name",
+                        size=10,
+                        aggs={
+                            "min_f1_score": Min(
+                                field="local_metrics.performance.test.f1_score"
+                            )
+                        },
+                    )
+                },
+            )
+        }
+        agg = Aggs(node_hierarchy, mappings=MAPPINGS, nested_autocorrect=True)
+        self.assertEqual(
+            agg.get_key(agg._deepest_linear_bucket_agg),
+            "local_metrics.field_class.name",
+        )
+
+        # week is last bucket linear bucket
+        node_hierarchy_2 = {
+            "week": DateHistogram(
+                field="date",
+                interval="1w",
+                aggs={
+                    "local_metrics.field_class.name": Terms(
+                        field="local_metrics.field_class.name", size=10
+                    ),
+                    "f1_score_above_threshold": Filter(
+                        filter={
+                            "range": {
+                                "local_metrics.performance.test.f1_score": {"gte": 0.5}
+                            }
+                        }
+                    ),
+                },
+            )
+        }
+        agg2 = Aggs(node_hierarchy_2, mappings=MAPPINGS, nested_autocorrect=True)
+        self.assertEqual(agg2.get_key(agg2._deepest_linear_bucket_agg), "week")
+
+    def test_grouped_by(self):
+        a = Aggs().aggs(
+            {
+                "some_agg": {
+                    "terms": {"field": "some_field"},
+                    "aggs": {"below_agg": {"terms": {"field": "other_field"}}},
+                }
+            }
+        )
+        self.assertEqual(a._groupby_ptr, a.root)
+        self.assertEqual(
+            a.agg("age_avg", "avg", field="age").to_dict(),
+            {
+                "some_agg": {
+                    "terms": {"field": "some_field"},
+                    "aggs": {"below_agg": {"terms": {"field": "other_field"}}},
+                },
+                "age_avg": {"avg": {"field": "age"}},
+            },
+        )
+
+        # select a specific agg
+        new_a = a.grouped_by("some_agg")
+        self.assertEqual(new_a._groupby_ptr, new_a.id_from_key("some_agg"))
+        self.assertEqual(
+            new_a.agg("age_avg", "avg", field="age").to_dict(),
+            {
+                "some_agg": {
+                    "terms": {"field": "some_field"},
+                    "aggs": {
+                        "below_agg": {"terms": {"field": "other_field"}},
+                        "age_avg": {"avg": {"field": "age"}},
+                    },
+                }
+            },
+        )
+
+        # deepest
+        last_a = a.grouped_by(deepest=True)
+        self.assertEqual(last_a._groupby_ptr, new_a.id_from_key("below_agg"))
+        self.assertEqual(
+            last_a.agg("age_avg", "avg", field="age").to_dict(),
+            {
+                "some_agg": {
+                    "terms": {"field": "some_field"},
+                    "aggs": {
+                        "below_agg": {
+                            "terms": {"field": "other_field"},
+                            "aggs": {"age_avg": {"avg": {"field": "age"}}},
+                        }
+                    },
+                }
+            },
+        )
